#-------------------------------------------------------------------------------
# @(#) ericsson-mgw/vstart/EngineConfig.pm ericsson-mgw_r4.1 Tuesday April 24 15:50:35 WEST 2007
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# Engine configuration for 3GPP ASN1 engine rule. Configuration specifically
# for the Ericsson Media Gateway Tech Pack.
# 
# Copyright (C) Vallent Software Systems (UK) 2007

package EngineConfig;

@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

use strict;
use Exporter ();

#-------------------------------------------------------------------------------
# The ASN1_3GPP rule instance in this EngineConfig is specifically configured to
# parse Ericsson Media Gateway 3GPP ASN.1 based performance measurement files. 
# 
#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my @rules = (
    {
        RULE_TYPE  => 'ASN1_3GPP',
        RULE_DESC  => 'Ericsson MGW ASN1 Interface',
        INPUT_FILE_DESCRIPTION  => ['^\w\d{8}\.\d{4}-\d{4}.*'],
        FILENAME_HEADER_FIELDS  => {
            FILE       => '(.+)',
            Type       => '^(\w{1}).+$',
            StartDate  => '^\w{1}(\d{8}).+$',
            StartTime => '^\w{1}\d{8}\.(\d{4}).+$',
            ElementInfo => '^\w{1}\d{8}\.\d{4}-\d{4}_(\w+)_\d+$',
#           GMT_difference => '^\w{1}\d{8}\.\d{4}([+-]?\d{0,4})-.+$',
        },
        
        ASN1_HEADER_COUNTERS_FOR_DATE_TIME_MANIP => [ qw(collectionBeginTime
                                                         measTimeStamp
                                                         measFileFooter
							 StartTime
							 StartDate) ],
        ASN1_ENABLE_PIF_COUNTER_IN_FILENAME      => 'True',
        ASN1_ENABLE_PIF_PER_MOID                 => 0,
        # ASN1_COPY_HEADER_TO_DATA_RECORDS         => [qw(senderName_ManagedElement)],
        ASN1_3GPP_BER_PACKAGE_NAME               => 'ASN1_3GPP_BER_Ericsson',

        ASN1_OBJECT_INSTANCE_ID_ELEMENT_NAME  => 'measObjInstId',
	
        ASN1_HEADER_INFO_FOR_PIF_FILENAME  => [qw(senderName_ManagedElement
                                                  senderName_MeContext
                                                  collectionBeginTime_Date
                                                  collectionBeginTime_Time)],
        
#	Switch off SUSPECT FLAG to get more data       
#        ASN1_SUSPECT_FLAG_ELEMENT_NAME           => 'suspectFlag',
#        ASN1_ALTERNATIVE_COUNTER_NULL_VALUE      => '-9999',
        ASN1_ALTERNATIVE_COUNTER_NULL_VALUE      => '0',
        ASN1_OUTPUT_BLOCK_ELEMENT_NAME           => 'measObjInstId',
        ASN1_3GPP_FILENAME_VALIDATION =>    {
            Type      => '^(A|B|C|D).+$',          
            StartDate => '^\w{1}(\d{8}).+$',
            StartTime => '^\w{1}\d{8}\.(\d{4}).+$',
#           Utc => '^\w{1}\d{8}\.\d{4}([+-]\d{4}).+$',
#           EndDate   => '^\w{1}\d{8}\.\d{4}-(\d{8}).*',
#           EndTime   => '^\w{1}\d{8}\.\d{4}-\d{8}\.(\d{4}).*',
#           UniqueID  => '^\w{1}\d{8}\.\d{4}-\d{8}\.\d{4}_(\d+)',
#           RC        => '^\w{1}\d{8}\.\d{4}-\d{8}\.\d{4}_\d+:(\d+)'
        },         
        'ASN1_OBJECT_INSTANCE_ID_DESCRIPTION' => {},
        'ASN1_ALT_OBJECT_INSTANCE_ID_NAMES' => {},
    }
);  

sub engine_config {
    return \@rules;
}

1;
